@@ -14,9 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 from torch import nn
 
@@ -24,10 +22,8 @@ from torch import nn
 class CTCHead(nn.Module):
     def __init__(self, in_channels, out_channels, fc_decay=0.0004, **kwargs):
         super(CTCHead, self).__init__()
-        
-        self.fc = nn.Linear(
-            in_channels,
-            out_channels)
+
+        self.fc = nn.Linear(in_channels, out_channels)
         self.softmax = nn.Softmax(dim=2)
         self.out_channels = out_channels
 
