@@ -59,8 +59,8 @@ class TextRecognizer(object):
         self.lang = config["lang"]
         self.rec_batch_num = config["batch_size"]
         self.rec_algorithm = config["Architecture"]["algorithm"]
-        self.rec_whitelist = config["whitelist"]
-        self.rec_blacklist = config["blacklist"]
+        self.whitelist = config["whitelist"]
+        self.blacklist = config["blacklist"]
 
         # Todo: Implement whitelist and blacklist in postprocessing step.
 
@@ -153,17 +153,20 @@ class TextRecognizer(object):
                 gsrm_slf_attn_bias2_list = np.concatenate(
                     gsrm_slf_attn_bias2_list
                 )
-
                 inputs = [
-                    torch.as_tensor(norm_img_batch).to(self.device),
-                    torch.as_tensor(encoder_word_pos_list).to(self.device),
-                    torch.as_tensor(gsrm_word_pos_list).to(self.device),
-                    torch.as_tensor(gsrm_slf_attn_bias1_list).to(self.device),
-                    torch.as_tensor(gsrm_slf_attn_bias2_list).to(self.device),
+                    torch.as_tensor(norm_img_batch, device=self.device),
+                    torch.as_tensor(encoder_word_pos_list, device=self.device),
+                    torch.as_tensor(gsrm_word_pos_list, device=self.device),
+                    torch.as_tensor(
+                        gsrm_slf_attn_bias1_list, device=self.device
+                    ),
+                    torch.as_tensor(
+                        gsrm_slf_attn_bias2_list, device=self.device
+                    ),
                 ]
                 self.predictor.to(self.device)
-
-                output_tensors = self.predictor(inputs[0], inputs[1:])
+                with torch.no_grad():
+                    output_tensors = self.predictor(inputs[0], inputs[1:])
                 outputs = []
                 for output_tensor in output_tensors.values():
                     output = output_tensor.cpu().data.numpy()
@@ -171,23 +174,24 @@ class TextRecognizer(object):
                 preds = {"predict": outputs[3]}
             else:
                 starttime = time.time()
-                imgs = torch.as_tensor(norm_img_batch)
-                input_tensors = imgs.to(self.device)
+                input_tensors = torch.as_tensor(
+                    norm_img_batch, device=self.device
+                )
                 self.predictor.to(self.device)
-
-                output_tensors = self.predictor(input_tensors)
+                with torch.no_grad():
+                    output_tensors = self.predictor(input_tensors)
 
                 preds = output_tensors.cpu().data.numpy()
                 # If both blacklist and whitelist are provided, whitelist is only used
-                if not self.rec_whitelist and self.rec_blacklist:
+                if not self.whitelist and self.blacklist:
                     self.mod_chars = np.arange(preds.shape[-1])
-                    black_list = self.char_ops.encode(self.rec_blacklist)
+                    black_list = self.char_ops.encode(self.blacklist)
                     black_list = np.array(black_list) + 1
                     self.mod_chars = np.setdiff1d(self.mod_chars, black_list)
-                elif self.rec_whitelist:
-                    white_list = self.char_ops.encode(self.rec_whitelist)
+                elif self.whitelist:
+                    white_list = self.char_ops.encode(self.whitelist)
                     self.mod_chars = np.append(white_list, [-1]) + 1
-                elif not self.rec_whitelist and not self.rec_blacklist:
+                elif not self.whitelist and not self.blacklist:
                     self.mod_chars = []
 
                 if len(self.mod_chars) != 0:
